@@ -3,6 +3,9 @@ import warnings
 import traceback
 import numpy as np
 import requests
+import os
+from .options import get_option, set_option
+from .indexer import ViIndexer
 from .errors import ModelError
 from typing import Any, List
 from abc import ABC, abstractmethod
@@ -32,23 +35,26 @@ def catch_vector_errors(func):
     """
     @functools.wraps(func)
     def catch_vector(*args, **kwargs):
-        try:
+        if get_option('catch_vector_errors') is False:
             return func(*args, **kwargs)
-        except:
-            warnings.warn("Unable to encode. Filling in with dummy vector.")
-            traceback.print_exc()
-            # get the vector length from the self body
-            vector_length = args[0].vector_length
-            if isinstance(args[1], str):
-                return [1e-7] * vector_length
-            elif isinstance(args[1], list):
-                # Return the list of vectors
-                return [[1e-7] * vector_length] * len(args[1])
-            else:
-                return [1e-7] * vector_length
+        else:
+            try:
+                return func(*args, **kwargs)
+            except:
+                warnings.warn("Unable to encode. Filling in with dummy vector.")
+                traceback.print_exc()
+                # get the vector length from the self body
+                vector_length = args[0].vector_length
+                if isinstance(args[1], str):
+                    return [1e-7] * vector_length
+                elif isinstance(args[1], list):
+                    # Return the list of vectors
+                    return [[1e-7] * vector_length] * len(args[1])
+                else:
+                    return [1e-7] * vector_length
     return catch_vector
 
-class Base2Vec:
+class Base2Vec(ViIndexer):
     """
         Base class for vector
     """
@@ -58,7 +64,7 @@ class Base2Vec:
     @classmethod
     def validate_model_url(cls, model_url: str, list_of_urls: List[str]):
         """
-            Validate the model url belongs in the list of urls. This is to help 
+            Validate the model url belongs in the list of urls. This is to help
             users to avoid mis-spelling the name of the model.
 
             # TODO:
@@ -67,7 +73,7 @@ class Base2Vec:
             Args:
                 model_url: The URl of the the model in question
                 list_of_urls: The list of URLS for the model in question
-        
+
         """
         if model_url in list_of_urls:
             return True
@@ -81,7 +87,7 @@ class Base2Vec:
         warnings.warn("We have not tested this url. Please use URL at your own risk." + \
             "Please use the is_url_working method to test if this is a working url if " + \
             "this is not a local directory.", UserWarning)
-    
+
     @staticmethod
     def is_url_working(url):
         response = requests.head(url)
@@ -108,7 +114,7 @@ class Base2Vec:
     def _vector_operation(self, vectors, vector_operation: str = "mean", axis=0):
         """
             Args:
-                Vectors: the list of vectors to include 
+                Vectors: the list of vectors to include
                 vector_operation: One of ['mean', 'minus', 'sum', 'min', 'max']
                 axis: The axis to which to perform the operation
         """
@@ -132,14 +138,14 @@ class Base2Vec:
             model_id.
         """
         if hasattr(self, '_name'):
-            return self._name
+            return self._name.replace('-', '_')
         elif hasattr(self, 'definition'):
             if '/' in self.definition.model_id:
-                return self.definition.model_id.split('/')[1]
+                return self.definition.model_id.split('/')[1].replace('-', '_')
             return self.definition.model_id
         return ''
-    
-    @__name__.setter        
+
+    @__name__.setter
     def __name__(self, value):
         """
             Set the name.
