@@ -17,25 +17,20 @@ __doc__ = USEModelDefinition.create_docs()
 
 class USE2Vec(BaseText2Vec):
     definition = USEModelDefinition
+    urls = {
+        "https://tfhub.dev/google/universal-sentence-encoder/4": {'vector_length': 512},
+        "https://tfhub.dev/google/universal-sentence-encoder-large/5": {'vector_length': 512}
+    }
     # or layer19
-    def __init__(self, model_url: str = 'https://tfhub.dev/google/universal-sentence-encoder/4'):
+    def __init__(self, model_url: str = "https://tfhub.dev/google/universal-sentence-encoder-large/5"):
         self.validate_model_url(model_url, list(self.urls.keys()))
         self.init(model_url)
         self.vector_length = 512
 
-    @property
-    def urls(self):
-        return {
-            "https://tfhub.dev/google/universal-sentence-encoder/4": {'vector_length': 512},
-            "https://tfhub.dev/google/universal-sentence-encoder-large/5": {'vector_length': 512}
-        }
-
     def init(self, model_url: str):
         self.model_url = model_url
         self.model = hub.load(self.model_url)
-        self.model_name = model_url.replace(
-            'https://tfhub.dev/google/', '').replace('/', '_')
-
+        self.model_name = model_url.replace('https://tfhub.dev/google/', '').replace('/', '_')
 
     @catch_vector_errors
     def encode(self, text):
