@@ -15,10 +15,12 @@ MODEL_REQUIREMENTS = {
 
     "encoders-text-tfhub-albert": "encoders-text-tfhub",
     "encoders-text-tfhub-bert": "encoders-text-tfhub-windows",
+    "encoders-text-tfhub-expertsbert": "encoders-text-tfhub",
     "encoders-text-tfhub-elmo": "encoders-text-tfhub",
     "encoders-text-tfhub-labse": "encoders-text-tfhub-windows",
     "encoders-text-tfhub-use": "encoders-text-tfhub-windows", 
     "encoders-text-tfhub-use-multi": "encoders-text-tfhub", 
+    "encoders-text-tfhub-use-transformer": "encoders-text-tfhub",
     "encoders-text-torch-transformers-legalbert": "encoders-text-torch-transformers",
     "encoders-text-tf-transformers-auto": "encoders-text-tf-transformers",
     "encoders-text-torch-transformers-auto": "encoders-text-torch-transformers",
@@ -26,7 +28,6 @@ MODEL_REQUIREMENTS = {
     "encoders-text-sentence-transformers": "encoders-text-sentence-transformers",
     "encoders-text-vectorai": None,
     
-    
     "encoders-image-tfhub-bit": "encoders-image-tfhub",
     "encoders-image-tfhub-resnet": "encoders-image-tfhub",
     "encoders-image-tfhub-inception": "encoders-image-tfhub",
@@ -34,10 +35,13 @@ MODEL_REQUIREMENTS = {
     "encoders-image-tfhub-mobilenet": "encoders-image-tfhub",
     "encoders-image-fastai-resnet": "encoders-image-fastai",
     "encoders-image-vectorai": None,
-    "encoders-image-tensorflow-face-detection": "encoders-image-tensorflow-face-detection",
+    "encoders-image-tf-face-detection": "encoders-image-tf-face-detection",
     
     "text-bi-encoder-tfhub-lareqa-qa": "encoders-text-tfhub",
     "text-bi-encoder-tfhub-use-qa": "encoders-text-tfhub",
     "text-bi-encoder-torch-dpr": "encoders-text-torch-transformers",
     
+    "encoders-code-transformers": "encoders-text-transformers",
+
+    "text-image-bi-encoder-clip": "clip"
 }
